==> config-api-0.3.8-sources.jar: org/wildfly/swarm/config/infinispan/cache_container/StringJdbcStore.java <==
package org.wildfly.swarm.config.infinispan.cache_container;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
import java.util.List;
import org.wildfly.swarm.config.runtime.Subresource;
/**
 * The cache JDBC store configuration.
 */
@ResourceType("store")
@Implicit
public class StringJdbcStore {

	private String key;
	private Long cacheLoaderLoads;
	private Long cacheLoaderMisses;
	private String dataSource;
	private String dialect;
	private Boolean fetchState;
	private Boolean passivation;
	private Boolean preload;
	private Map properties;
	private Boolean purge;
	private Boolean shared;
	private Boolean singleton;
	private StringJdbcStoreResources subresources = new StringJdbcStoreResources();
	private ThroughWrite throughWrite;
	private BehindWrite behindWrite;
	private StringTable stringTable;

	public StringJdbcStore() {
		this.key = "string-jdbc";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The number of cache loader node loads. May return null if the cache is not started.
	 */
	@ModelNodeBinding(detypedName = "cache-loader-loads")
	public Long cacheLoaderLoads() {
		return this.cacheLoaderLoads;
	}

	/**
	 * The number of cache loader node loads. May return null if the cache is not started.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore cacheLoaderLoads(Long value) {
		this.cacheLoaderLoads = value;
		return (StringJdbcStore) this;
	}

	/**
	 * The number of cache loader node misses. May return null if the cache is not started.
	 */
	@ModelNodeBinding(detypedName = "cache-loader-misses")
	public Long cacheLoaderMisses() {
		return this.cacheLoaderMisses;
	}

	/**
	 * The number of cache loader node misses. May return null if the cache is not started.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore cacheLoaderMisses(Long value) {
		this.cacheLoaderMisses = value;
		return (StringJdbcStore) this;
	}

	/**
	 * References the data source used to connect to this store.
	 */
	@ModelNodeBinding(detypedName = "data-source")
	public String dataSource() {
		return this.dataSource;
	}

	/**
	 * References the data source used to connect to this store.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore dataSource(String value) {
		this.dataSource = value;
		return (StringJdbcStore) this;
	}

	/**
	 * The dialect of this datastore.
	 */
	@ModelNodeBinding(detypedName = "dialect")
	public String dialect() {
		return this.dialect;
	}

	/**
	 * The dialect of this datastore.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore dialect(String value) {
		this.dialect = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, fetch persistent state when joining a cluster. If multiple cache stores are chained, only one of them can have this property enabled.
	 */
	@ModelNodeBinding(detypedName = "fetch-state")
	public Boolean fetchState() {
		return this.fetchState;
	}

	/**
	 * If true, fetch persistent state when joining a cluster. If multiple cache stores are chained, only one of them can have this property enabled.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore fetchState(Boolean value) {
		this.fetchState = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, data is only written to the cache store when it is evicted from memory, a phenomenon known as 'passivation'. Next time the data is requested, it will be 'activated' which means that data will be brought back to memory and removed from the persistent store. f false, the cache store contains a copy of the contents in memory, so writes to cache result in cache store writes. This essentially gives you a 'write-through' configuration.
	 */
	@ModelNodeBinding(detypedName = "passivation")
	public Boolean passivation() {
		return this.passivation;
	}

	/**
	 * If true, data is only written to the cache store when it is evicted from memory, a phenomenon known as 'passivation'. Next time the data is requested, it will be 'activated' which means that data will be brought back to memory and removed from the persistent store. f false, the cache store contains a copy of the contents in memory, so writes to cache result in cache store writes. This essentially gives you a 'write-through' configuration.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore passivation(Boolean value) {
		this.passivation = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, when the cache starts, data stored in the cache store will be pre-loaded into memory. This is particularly useful when data in the cache store will be needed immediately after startup and you want to avoid cache operations being delayed as a result of loading this data lazily. Can be used to provide a 'warm-cache' on startup, however there is a performance penalty as startup time is affected by this process.
	 */
	@ModelNodeBinding(detypedName = "preload")
	public Boolean preload() {
		return this.preload;
	}

	/**
	 * If true, when the cache starts, data stored in the cache store will be pre-loaded into memory. This is particularly useful when data in the cache store will be needed immediately after startup and you want to avoid cache operations being delayed as a result of loading this data lazily. Can be used to provide a 'warm-cache' on startup, however there is a performance penalty as startup time is affected by this process.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore preload(Boolean value) {
		this.preload = value;
		return (StringJdbcStore) this;
	}

	/**
	 * A list of cache store properties.
	 */
	@ModelNodeBinding(detypedName = "properties")
	public Map properties() {
		return this.properties;
	}

	/**
	 * A list of cache store properties.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore properties(Map value) {
		this.properties = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, purges this cache store when it starts up.
	 */
	@ModelNodeBinding(detypedName = "purge")
	public Boolean purge() {
		return this.purge;
	}

	/**
	 * If true, purges this cache store when it starts up.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore purge(Boolean value) {
		this.purge = value;
		return (StringJdbcStore) this;
	}

	/**
	 * This setting should be set to true when multiple cache instances share the same cache store (e.g., multiple nodes in a cluster using a JDBC-based CacheStore pointing to the same, shared database.) Setting this to true avoids multiple cache instances writing the same modification multiple times. If enabled, only the node where the modification originated will write to the cache store. If disabled, each individual cache reacts to a potential remote update by storing the data to the cache store.
	 */
	@ModelNodeBinding(detypedName = "shared")
	public Boolean shared() {
		return this.shared;
	}

	/**
	 * This setting should be set to true when multiple cache instances share the same cache store (e.g., multiple nodes in a cluster using a JDBC-based CacheStore pointing to the same, shared database.) Setting this to true avoids multiple cache instances writing the same modification multiple times. If enabled, only the node where the modification originated will write to the cache store. If disabled, each individual cache reacts to a potential remote update by storing the data to the cache store.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore shared(Boolean value) {
		this.shared = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, the singleton store cache store is enabled. SingletonStore is a delegating cache store used for situations when only one instance in a cluster should interact with the underlying store.
	 */
	@ModelNodeBinding(detypedName = "singleton")
	public Boolean singleton() {
		return this.singleton;
	}

	/**
	 * If true, the singleton store cache store is enabled. SingletonStore is a delegating cache store used for situations when only one instance in a cluster should interact with the underlying store.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore singleton(Boolean value) {
		this.singleton = value;
		return (StringJdbcStore) this;
	}

	public StringJdbcStoreResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all org.wildfly.swarm.config.infinispan.cache_container.Property objects to this subresource
	 * @return this
	 * @param value List of org.wildfly.swarm.config.infinispan.cache_container.Property objects.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore propertys(
			List<org.wildfly.swarm.config.infinispan.cache_container.Property> value) {
		this.subresources.propertys.addAll(value);
		return (StringJdbcStore) this;
	}

	/**
	 * Add the org.wildfly.swarm.config.infinispan.cache_container.Property object to the list of subresources
	 * @param value The org.wildfly.swarm.config.infinispan.cache_container.Property to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore property(Property value) {
		this.subresources.propertys.add(value);
		return (StringJdbcStore) this;
	}

	/**
	 * Child mutators for StringJdbcStore
	 */
	public class StringJdbcStoreResources {
		/**
		 * A cache store property with name and value.
		 */
		private List<org.wildfly.swarm.config.infinispan.cache_container.Property> propertys = new java.util.ArrayList<>();

		/**
		 * Get the list of org.wildfly.swarm.config.infinispan.cache_container.Property resources
		 * @return the list of resources
		 */
		@Subresource
		public List<Property> propertys() {
			return this.propertys;
		}
	}

	/**
	 * Configures a cache store as write-through.
	 */
	@Subresource
	public ThroughWrite throughWrite() {
		return this.throughWrite;
	}

	/**
	 * Configures a cache store as write-through.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore throughWrite(ThroughWrite value) {
		this.throughWrite = value;
		return (StringJdbcStore) this;
	}

	/**
	 * Configures a cache store as write-behind instead of write-through.
	 */
	@Subresource
	public BehindWrite behindWrite() {
		return this.behindWrite;
	}

	/**
	 * Configures a cache store as write-behind instead of write-through.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore behindWrite(BehindWrite value) {
		this.behindWrite = value;
		return (StringJdbcStore) this;
	}

	/**
	 * Defines a table used to store cache entries whose keys can be expressed as strings.
	 */
	@Subresource
	public StringTable stringTable() {
		return this.stringTable;
	}

	/**
	 * Defines a table used to store cache entries whose keys can be expressed as strings.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore stringTable(StringTable value) {
		this.stringTable = value;
		return (StringJdbcStore) this;
	}
}

==> config-api-0.3.9-sources.jar: org/wildfly/swarm/config/infinispan/cache_container/StringJdbcStore.java <==
package org.wildfly.swarm.config.infinispan.cache_container;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
import java.util.List;
import org.wildfly.swarm.config.runtime.Subresource;
/**
 * The cache JDBC store configuration.
 */
@ResourceType("store")
@Implicit
public class StringJdbcStore<T extends StringJdbcStore> {

	private String key;
	private Long cacheLoaderLoads;
	private Long cacheLoaderMisses;
	private String dataSource;
	private String dialect;
	private Boolean fetchState;
	private Boolean passivation;
	private Boolean preload;
	private Map properties;
	private Boolean purge;
	private Boolean shared;
	private Boolean singleton;
	private StringJdbcStoreResources subresources = new StringJdbcStoreResources();
	private ThroughWrite throughWrite;
	private BehindWrite behindWrite;
	private StringTable stringTable;

	public StringJdbcStore() {
		this.key = "string-jdbc";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The number of cache loader node loads. May return null if the cache is not started.
	 */
	@ModelNodeBinding(detypedName = "cache-loader-loads")
	public Long cacheLoaderLoads() {
		return this.cacheLoaderLoads;
	}

	/**
	 * The number of cache loader node loads. May return null if the cache is not started.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore cacheLoaderLoads(Long value) {
		this.cacheLoaderLoads = value;
		return (StringJdbcStore) this;
	}

	/**
	 * The number of cache loader node misses. May return null if the cache is not started.
	 */
	@ModelNodeBinding(detypedName = "cache-loader-misses")
	public Long cacheLoaderMisses() {
		return this.cacheLoaderMisses;
	}

	/**
	 * The number of cache loader node misses. May return null if the cache is not started.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore cacheLoaderMisses(Long value) {
		this.cacheLoaderMisses = value;
		return (StringJdbcStore) this;
	}

	/**
	 * References the data source used to connect to this store.
	 */
	@ModelNodeBinding(detypedName = "data-source")
	public String dataSource() {
		return this.dataSource;
	}

	/**
	 * References the data source used to connect to this store.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore dataSource(String value) {
		this.dataSource = value;
		return (StringJdbcStore) this;
	}

	/**
	 * The dialect of this datastore.
	 */
	@ModelNodeBinding(detypedName = "dialect")
	public String dialect() {
		return this.dialect;
	}

	/**
	 * The dialect of this datastore.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore dialect(String value) {
		this.dialect = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, fetch persistent state when joining a cluster. If multiple cache stores are chained, only one of them can have this property enabled.
	 */
	@ModelNodeBinding(detypedName = "fetch-state")
	public Boolean fetchState() {
		return this.fetchState;
	}

	/**
	 * If true, fetch persistent state when joining a cluster. If multiple cache stores are chained, only one of them can have this property enabled.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore fetchState(Boolean value) {
		this.fetchState = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, data is only written to the cache store when it is evicted from memory, a phenomenon known as 'passivation'. Next time the data is requested, it will be 'activated' which means that data will be brought back to memory and removed from the persistent store. f false, the cache store contains a copy of the contents in memory, so writes to cache result in cache store writes. This essentially gives you a 'write-through' configuration.
	 */
	@ModelNodeBinding(detypedName = "passivation")
	public Boolean passivation() {
		return this.passivation;
	}

	/**
	 * If true, data is only written to the cache store when it is evicted from memory, a phenomenon known as 'passivation'. Next time the data is requested, it will be 'activated' which means that data will be brought back to memory and removed from the persistent store. f false, the cache store contains a copy of the contents in memory, so writes to cache result in cache store writes. This essentially gives you a 'write-through' configuration.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore passivation(Boolean value) {
		this.passivation = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, when the cache starts, data stored in the cache store will be pre-loaded into memory. This is particularly useful when data in the cache store will be needed immediately after startup and you want to avoid cache operations being delayed as a result of loading this data lazily. Can be used to provide a 'warm-cache' on startup, however there is a performance penalty as startup time is affected by this process.
	 */
	@ModelNodeBinding(detypedName = "preload")
	public Boolean preload() {
		return this.preload;
	}

	/**
	 * If true, when the cache starts, data stored in the cache store will be pre-loaded into memory. This is particularly useful when data in the cache store will be needed immediately after startup and you want to avoid cache operations being delayed as a result of loading this data lazily. Can be used to provide a 'warm-cache' on startup, however there is a performance penalty as startup time is affected by this process.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore preload(Boolean value) {
		this.preload = value;
		return (StringJdbcStore) this;
	}

	/**
	 * A list of cache store properties.
	 */
	@ModelNodeBinding(detypedName = "properties")
	public Map properties() {
		return this.properties;
	}

	/**
	 * A list of cache store properties.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore properties(Map value) {
		this.properties = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, purges this cache store when it starts up.
	 */
	@ModelNodeBinding(detypedName = "purge")
	public Boolean purge() {
		return this.purge;
	}

	/**
	 * If true, purges this cache store when it starts up.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore purge(Boolean value) {
		this.purge = value;
		return (StringJdbcStore) this;
	}

	/**
	 * This setting should be set to true when multiple cache instances share the same cache store (e.g., multiple nodes in a cluster using a JDBC-based CacheStore pointing to the same, shared database.) Setting this to true avoids multiple cache instances writing the same modification multiple times. If enabled, only the node where the modification originated will write to the cache store. If disabled, each individual cache reacts to a potential remote update by storing the data to the cache store.
	 */
	@ModelNodeBinding(detypedName = "shared")
	public Boolean shared() {
		return this.shared;
	}

	/**
	 * This setting should be set to true when multiple cache instances share the same cache store (e.g., multiple nodes in a cluster using a JDBC-based CacheStore pointing to the same, shared database.) Setting this to true avoids multiple cache instances writing the same modification multiple times. If enabled, only the node where the modification originated will write to the cache store. If disabled, each individual cache reacts to a potential remote update by storing the data to the cache store.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore shared(Boolean value) {
		this.shared = value;
		return (StringJdbcStore) this;
	}

	/**
	 * If true, the singleton store cache store is enabled. SingletonStore is a delegating cache store used for situations when only one instance in a cluster should interact with the underlying store.
	 */
	@ModelNodeBinding(detypedName = "singleton")
	public Boolean singleton() {
		return this.singleton;
	}

	/**
	 * If true, the singleton store cache store is enabled. SingletonStore is a delegating cache store used for situations when only one instance in a cluster should interact with the underlying store.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore singleton(Boolean value) {
		this.singleton = value;
		return (StringJdbcStore) this;
	}

	public StringJdbcStoreResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all org.wildfly.swarm.config.infinispan.cache_container.Property objects to this subresource
	 * @return this
	 * @param value List of org.wildfly.swarm.config.infinispan.cache_container.Property objects.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore propertys(
			List<org.wildfly.swarm.config.infinispan.cache_container.Property> value) {
		this.subresources.propertys.addAll(value);
		return (StringJdbcStore) this;
	}

	/**
	 * Add the org.wildfly.swarm.config.infinispan.cache_container.Property object to the list of subresources
	 * @param value The org.wildfly.swarm.config.infinispan.cache_container.Property to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore property(Property value) {
		this.subresources.propertys.add(value);
		return (StringJdbcStore) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.infinispan.cache_container.Property object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.infinispan.cache_container.Property resource
	 * @param config The org.wildfly.swarm.config.infinispan.cache_container.PropertyConfigurator to use
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore property(String childKey, PropertyConfigurator config) {
		org.wildfly.swarm.config.infinispan.cache_container.Property child = new org.wildfly.swarm.config.infinispan.cache_container.Property(
				childKey);
		config.configure(child);
		property(child);
		return (StringJdbcStore) this;
	}

	/**
	 * Child mutators for StringJdbcStore
	 */
	public class StringJdbcStoreResources {
		/**
		 * A cache store property with name and value.
		 */
		private List<org.wildfly.swarm.config.infinispan.cache_container.Property> propertys = new java.util.ArrayList<>();

		/**
		 * Get the list of org.wildfly.swarm.config.infinispan.cache_container.Property resources
		 * @return the list of resources
		 */
		@Subresource
		public List<Property> propertys() {
			return this.propertys;
		}
	}

	/**
	 * Configures a cache store as write-through.
	 */
	@Subresource
	public ThroughWrite throughWrite() {
		return this.throughWrite;
	}

	/**
	 * Configures a cache store as write-through.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore throughWrite(ThroughWrite value) {
		this.throughWrite = value;
		return (StringJdbcStore) this;
	}

	/**
	 * Configures a cache store as write-behind instead of write-through.
	 */
	@Subresource
	public BehindWrite behindWrite() {
		return this.behindWrite;
	}

	/**
	 * Configures a cache store as write-behind instead of write-through.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore behindWrite(BehindWrite value) {
		this.behindWrite = value;
		return (StringJdbcStore) this;
	}

	/**
	 * Defines a table used to store cache entries whose keys can be expressed as strings.
	 */
	@Subresource
	public StringTable stringTable() {
		return this.stringTable;
	}

	/**
	 * Defines a table used to store cache entries whose keys can be expressed as strings.
	 */
	@SuppressWarnings("unchecked")
	public StringJdbcStore stringTable(StringTable value) {
		this.stringTable = value;
		return (StringJdbcStore) this;
	}
}
